# Copyright (C) 2018 Michael Pilosov

r"""
This subpackage provides methods for post-processing solutions to stochastic inverse problems solved using the Consistent Bayesian formulation.

* :mod:`~cbayes.postProcess.metrics` provides utility functions for comparing solutions using a variety of metric on measures and densities.

* :mod:`~cbayes.postProcess.plot` provides plotting utilities using the matplotlib pyplot backend. 

"""
__all__ = ["metrics", "plot"]
